using System.Collections.ObjectModel;
using System.Diagnostics;
using System.Drawing.Imaging;
using System.IO;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using CODE.Framework.Wpf.Documents;
using CODE.Framework.Wpf.Mvvm;

namespace DocumentExamples.Models.Print
{
    public class CustomerListViewModel : ViewModel
    {
        public CustomerListViewModel()
        {
            Customers = new ObservableCollection<StandardViewModel>();

            var bitmapImage = new BitmapImage();
            using (var memory = new MemoryStream())
            {
                Properties.Resources.customer_service.Save(memory, ImageFormat.Png);
                memory.Position = 0;
                bitmapImage.BeginInit();
                bitmapImage.StreamSource = memory;
                bitmapImage.CacheOption = BitmapCacheOption.OnLoad;
                bitmapImage.EndInit();
            }
            var image = new ImageBrush(bitmapImage) {Stretch = Stretch.UniformToFill};

            for (var i = 0; i < 100; i++)
            {
                Customers.Add(new StandardViewModel
                    {
                        Text1 = "Customer #" + (i + 1),
                        Text2 = "6605 Cypresswood Dr.",
                        Text3 = "Suite 300",
                        Text4 = "Spring, TX 77379",
                        Text5 = "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.",
                        Image1 = image
                    });
            }

            Actions.Add(new ViewAction("Save", brushResourceKey: "CODE.Framework-Icon-Save", execute: (a, o) =>
                {
                    var doc = Controller.GetDocumentForModel(this);
                    if (doc == null) return;
                    doc.SaveAsXps(@"d:\Test.xps");
                    Process.Start(@"d:\Test.xps");
                }));
            Actions.Add(new ViewAction("Print", brushResourceKey: "CODE.Framework-Icon-Print", execute: (a, o) =>
                {
                    var doc = Controller.GetDocumentForModel(this);
                    if (doc == null) return;
                    doc.Print();
                }));
            Actions.Add(new CloseCurrentViewAction(this, beginGroup: true));
        }

        public ObservableCollection<StandardViewModel> Customers { get; set; }
    }
}
